@@ -19,6 +19,7 @@ import platform
 import sys
 
 from cdpcli import LIST_TYPE
+from cdpcli import RELEASE
 from cdpcli import VERSION
 from cdpcli import xform_name
 from cdpcli.argparser import ArgTableArgParser
@@ -36,6 +37,7 @@ from cdpcli.client import Context
 from cdpcli.compat import copy_kwargs
 from cdpcli.compat import OrderedDict
 from cdpcli.compat import six
+from cdpcli.config import Config
 from cdpcli.endpoint import EndpointCreator
 from cdpcli.endpoint import EndpointResolver
 from cdpcli.extensions.arguments import OverrideRequiredArgsArgument
@@ -96,6 +98,7 @@ class CLIDriver(object):
         try:
             self._handle_top_level_args(parsed_args)
             self._warn_for_old_python()
+            self._warn_for_non_public_release()
             return command_table[parsed_args.command](
                 self._client_creator, remaining, parsed_args)
         except Exception as e:
@@ -183,6 +186,7 @@ class CLIDriver(object):
           action=option_params.get('action'),
           required=option_params.get('required'),
           choices=option_params.get('choices'),
+          cli_type_name=option_params.get('type'),
           hidden=option_params.get('hidden', False))
 
     def _handle_top_level_args(self, args):
@@ -226,12 +230,19 @@ class CLIDriver(object):
 
     def _warn_for_old_python(self):
         if sys.version_info[0] < 3 or \
-                (sys.version_info[0] == 3 and sys.version_info[1] < 5):
+                (sys.version_info[0] == 3 and sys.version_info[1] < 6):
             LOG.warn('You are running the CDP CLI under Python %s. The CDP CLI '
-                     'will require Python 3.5 or higher starting in '
+                     'will require Python 3.6 or higher starting in '
                      'January 2021. '
                      'Please upgrade now!', sys.version)
 
+    def _warn_for_non_public_release(self):
+        if RELEASE != 'PUBLIC':
+            LOG.warn('You are running a {0} release of the CDP CLI, which '
+                     'has different capabilities from the standard public '
+                     'release. Find the public release at: '
+                     'https://pypi.org/project/cdpcli/'.format(RELEASE))
+
 
 class ServiceCommand(CLICommand):
 
@@ -409,11 +420,20 @@ class ServiceOperation(object):
         if parsed_globals.verify_tls and ca_bundle is not None:
             tls_verification = ca_bundle
 
+        # Retrieve values passed for extra client configuration.
+        config_kwargs = {}
+        if parsed_globals.read_timeout is not None:
+            config_kwargs['read_timeout'] = int(parsed_globals.read_timeout)
+        if parsed_globals.connect_timeout is not None:
+            config_kwargs['connect_timeout'] = int(parsed_globals.connect_timeout)
+        config = Config(**config_kwargs)
+
         client = client_creator.create_client(
             self._operation_model.service_model.service_name,
             parsed_globals.endpoint_url,
             tls_verification,
-            client_creator.context.get_credentials())
+            client_creator.context.get_credentials(parsed_globals),
+            client_config=config)
         return self._invoke_operation_callers(client,
                                               call_parameters,
                                               parsed_args,
